pub struct Opts {Show 15 fields
pub release: bool,
pub precompress: bool,
pub hot_reload: bool,
pub project: Option<String>,
pub features: Vec<String>,
pub lib_features: Vec<String>,
pub lib_cargo_args: Option<Vec<String>>,
pub bin_features: Vec<String>,
pub bin_cargo_args: Option<Vec<String>>,
pub wasm_debug: bool,
pub verbose: u8,
pub js_minify: bool,
pub split: bool,
pub frontend_only: bool,
pub server_only: bool,
}Fields
release: boolBuild artifacts in release mode, with optimizations.
precompress: boolPrecompress static assets with gzip and brotli. Applies to release builds only.
hot_reload: boolTurn on partial hot-reloading. Requires rust nightly [beta]
project: Option<String>Which project to use, from a list of projects defined in a workspace
features: Vec<String>The features to use when compiling all targets
lib_features: Vec<String>The features to use when compiling the lib target
lib_cargo_args: Option<Vec<String>>The cargo flags to pass to cargo when compiling the lib target
bin_features: Vec<String>The features to use when compiling the bin target
bin_cargo_args: Option<Vec<String>>The cargo flags to pass to cargo when compiling the bin target
wasm_debug: boolInclude debug information in Wasm output. Includes source maps and DWARF debug info.
verbose: u8Verbosity (none: info, errors & warnings, -v: verbose, -vv: very verbose).
js_minify: boolMinify javascript assets with swc. Applies to release builds only.
split: boolSplit WASM binary based on #[lazy] macros.
frontend_only: boolOnly build the frontend.
server_only: boolOnly build the server.